MAPBOX_ACCESS_TOKEN = 'pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpejY4NXVycTA2emYycXBndHRqcmZ3N3gifQ.rJcFIG214AriISLbB6B5aw';

// create wkt polygon
const format = new ol.format.WKT();
const feature = format.readFeature(polygon, {
  dataProjection: 'EPSG:4326',
	featureProjection: 'EPSG:3857'
});


// Create layers
const mapbox = new ol.layer.Tile({
  name: 'mapbox',
  source: new ol.source.XYZ({
    url:'https://api.tiles.mapbox.com/v4/mapbox.light/{z}/{x}/{y}.png?access_token='+MAPBOX_ACCESS_TOKEN
  })
});

const vector = new ol.layer.Vector({
  name: 'polygon',
  source: new ol.source.Vector({
    features: [feature]
  })
});

// create map
const map = new ol.Map({
  target: 'minimap',
  layers: [mapbox, vector],
  view: new ol.View({
    center: ol.proj.fromLonLat([-99.19, 19.61]),
    zoom: 4,
    minZoom:4
  })
});

// fit to polygon
map.getView().fit(feature.getGeometry());


// show first date and current date
let currentDate;
let currentOpacity = 1;

if (labels && labels.length > 0) {
  currentDate = labels[0];
  addImageLayer(currentDate)
}


function addImageLayer(labelDate) {
  $.ajax({
    type: 'POST',
    dataType: "json",
    data: {'purchase_id': purchase_id, 'report': zone, 'date': labelDate},
    url: '/reports/tiles/tileinfo',
    success: function (data) {

      currentDate = labelDate;
      removeImageLayers()

      // add layer
      getSelectedCheckboxes().forEach(layer_type => {
        const xyz = new ol.layer.Tile({
          name: layer_type,
          opacity: (layer_type == 'TCI') ? 1 : currentOpacity,
          source: new ol.source.XYZ({
            projection: 'EPSG:3857',
            url: '/reports/tiles/'+purchase_id+'/'+zone+'/'+layer_type+'/'+labelDate+'/{z}/{x}/{-y}.png',
            tilePixelRatio: 2,
            minZoom: data.zoom.min,
            maxZoom: data.zoom.max
          })
        });

        map.addLayer(xyz);
      })

      // fit and zoom
      map.getView().setMinZoom(data.zoom.min);
      map.getView().setMaxZoom(data.zoom.max);
    }
  });
}

function removeImageLayers() {
  map.getLayers().getArray().slice().forEach(layer => {
    if(layer.get('name') != 'mapbox' && layer.get('name') != 'polygon') {
      map.removeLayer(layer)
    }
  })
}

function setOpacity(value) {
  currentOpacity = value;
  map.getLayers().getArray().slice().forEach(layer => {
    if(layer.get('name') != 'mapbox' && layer.get('name') != 'polygon' && layer.get('name') != 'TCI') {
      layer.setOpacity(value)
    }
  })
}

function getSelectedCheckboxes() {
  const inputs = $("input[name=layer_type]:checked");
  let values = []

  Object.keys(inputs).forEach(key => {
    let value = inputs[key].value;
    if (value) {values.push(value)}
  })

  return values;
}

function getChartDataIndex(id) {
  let foundIndex;

  myChart.config.data.datasets.forEach(function (data, index) {
    let label = 'sclcheck-' + data.label.toLowerCase().replace(' ', '-');
    if (label === id) {
      foundIndex = index;
    }
  })

  return foundIndex;
}

$('input[name=layer_type]').on('click', function(){
  const input = $(this);
  const index = getChartDataIndex(input.parent().attr('id'));

  if (index > -1) {
    myChart.getDatasetMeta(index).hidden=!input.prop("checked");
    myChart.update()
  }

  addImageLayer(currentDate);
});
